==> jc-1.4.0.tar.gz: polyglot/util/Pair.c <==
// public class polyglot.util.Pair

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 98b787b92ac6a3b9 polyglot_util_Pair

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header polyglot_util_Pair

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "polyglot/util/Pair.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// java.lang.Object part1
static _jc_field _jc_polyglot_util_Pair$field_info$part1 = {
	.name=		"part1",
	.signature=	"Ljava/lang/Object;",
	.class=		&_jc_polyglot_util_Pair$type,
	.type=		&_jc_java_lang_Object$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_polyglot_util_Pair$object, refs[-1].polyglot_util_Pair.part1),
};

// java.lang.Object part2
static _jc_field _jc_polyglot_util_Pair$field_info$part2 = {
	.name=		"part2",
	.signature=	"Ljava/lang/Object;",
	.class=		&_jc_polyglot_util_Pair$type,
	.type=		&_jc_java_lang_Object$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_polyglot_util_Pair$object, refs[-1].polyglot_util_Pair.part2),
};

// Fields
static _jc_field *const _jc_polyglot_util_Pair$fields[] = {
	&_jc_polyglot_util_Pair$field_info$part1,
	&_jc_polyglot_util_Pair$field_info$part2
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.Object, java.lang.Object)
//

static _jc_linenum _jc_polyglot_util_Pair$linenum_table$_init$1b34a4ef37055d19[];

static const unsigned char _jc_polyglot_util_Pair$param_ptypes$_init$1b34a4ef37055d19[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_polyglot_util_Pair$param_types$_init$1b34a4ef37055d19[] = {
	&_jc_java_lang_Object$type,
	&_jc_java_lang_Object$type
};

_jc_method _jc_polyglot_util_Pair$method_info$_init$1b34a4ef37055d19 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/Object;Ljava/lang/Object;)V",
	.class=			&_jc_polyglot_util_Pair$type,
	.param_types=		&_jc_polyglot_util_Pair$param_types$_init$1b34a4ef37055d19,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_polyglot_util_Pair$param_ptypes$_init$1b34a4ef37055d19,
	.signature_hash=	_JC_JLONG(0x1b34a4ef37055d19),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_util_Pair$method$_init$1b34a4ef37055d19,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_polyglot_util_Pair$linenum_table$_init$1b34a4ef37055d19
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_util_Pair, _init$1b34a4ef37055d19);

void
_jc_polyglot_util_Pair$method$_init$1b34a4ef37055d19(_jc_env *const env, _jc_polyglot_util_Pair$object *this, _jc_java_lang_Object$object *param0, _jc_java_lang_Object$object *param1)
{
	struct _jc_polyglot_util_Pair$object *r0;
	struct _jc_java_lang_Object$object *r1;
	struct _jc_java_lang_Object$object *r2;

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(11);				// 0
	_JC_REF_FIELD(env, r0, polyglot_util_Pair, part1) = r1;
	_JC_LINE_NUMBER(12);				// 1
	_JC_REF_FIELD(env, r0, polyglot_util_Pair, part2) = r2;
	_JC_LINE_NUMBER(13);				// 2
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.Object part1()
//

static _jc_linenum _jc_polyglot_util_Pair$linenum_table$part1$0c1e939f4cba35c8[];

static const unsigned char _jc_polyglot_util_Pair$param_ptypes$part1$0c1e939f4cba35c8[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_polyglot_util_Pair$method_info$part1$0c1e939f4cba35c8 = {
	.name=			"part1",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_polyglot_util_Pair$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_polyglot_util_Pair$param_ptypes$part1$0c1e939f4cba35c8,
	.signature_hash=	_JC_JLONG(0xc1e939f4cba35c8),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_util_Pair$method$part1$0c1e939f4cba35c8,
	.vtable_index=		_JC_OFFSETOF(struct _jc_polyglot_util_Pair$vtable, polyglot_util_Pair.part1$0c1e939f4cba35c8) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_util_Pair$linenum_table$part1$0c1e939f4cba35c8
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_util_Pair, part1$0c1e939f4cba35c8);

_jc_java_lang_Object$object *
_jc_polyglot_util_Pair$method$part1$0c1e939f4cba35c8(_jc_env *const env, _jc_polyglot_util_Pair$object *this)
{
	struct _jc_polyglot_util_Pair$object *r0;
	struct _jc_java_lang_Object$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(16);				// 0
	r1 = _JC_REF_FIELD(env, r0, polyglot_util_Pair, part1);
	return r1;
}

//
// public java.lang.Object part2()
//

static _jc_linenum _jc_polyglot_util_Pair$linenum_table$part2$7912c7411ed9b452[];

static const unsigned char _jc_polyglot_util_Pair$param_ptypes$part2$7912c7411ed9b452[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_polyglot_util_Pair$method_info$part2$7912c7411ed9b452 = {
	.name=			"part2",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_polyglot_util_Pair$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_polyglot_util_Pair$param_ptypes$part2$7912c7411ed9b452,
	.signature_hash=	_JC_JLONG(0x7912c7411ed9b452),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_util_Pair$method$part2$7912c7411ed9b452,
	.vtable_index=		_JC_OFFSETOF(struct _jc_polyglot_util_Pair$vtable, polyglot_util_Pair.part2$7912c7411ed9b452) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_util_Pair$linenum_table$part2$7912c7411ed9b452
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_util_Pair, part2$7912c7411ed9b452);

_jc_java_lang_Object$object *
_jc_polyglot_util_Pair$method$part2$7912c7411ed9b452(_jc_env *const env, _jc_polyglot_util_Pair$object *this)
{
	struct _jc_polyglot_util_Pair$object *r0;
	struct _jc_java_lang_Object$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(20);				// 0
	r1 = _JC_REF_FIELD(env, r0, polyglot_util_Pair, part2);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_polyglot_util_Pair$methods[] = {
	&_jc_polyglot_util_Pair$method_info$_init$1b34a4ef37055d19,
	&_jc_polyglot_util_Pair$method_info$part1$0c1e939f4cba35c8,
	&_jc_polyglot_util_Pair$method_info$part2$7912c7411ed9b452
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_polyglot_util_Pair$instanceof_hash_bucket_57[] = {
	&_jc_polyglot_util_Pair$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_util_Pair$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_polyglot_util_Pair$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[57]=	_jc_polyglot_util_Pair$instanceof_hash_bucket_57,
	[113]=	_jc_polyglot_util_Pair$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_polyglot_util_Pair$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_polyglot_util_Pair$vtype _jc_polyglot_util_Pair$type = {
    .type= {
	.name=			"polyglot/util/Pair",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x98b787b92ac6a3b9),
		.source_file=		"Pair.java",
		.instance_size=		sizeof(_jc_polyglot_util_Pair$refs) + sizeof(_jc_polyglot_util_Pair$object),
		.num_virtual_refs=	2,
		.num_fields=		sizeof(_jc_polyglot_util_Pair$fields) / sizeof(*_jc_polyglot_util_Pair$fields),
		.fields=		_jc_polyglot_util_Pair$fields,
		.num_methods=		sizeof(_jc_polyglot_util_Pair$methods) / sizeof(*_jc_polyglot_util_Pair$methods),
		.methods=		_jc_polyglot_util_Pair$methods,
		.instanceof_hash_table=	_jc_polyglot_util_Pair$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_polyglot_util_Pair$class_depends) / sizeof(*_jc_polyglot_util_Pair$class_depends),
		.class_depends=		_jc_polyglot_util_Pair$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.polyglot_util_Pair= {
	    .part1$0c1e939f4cba35c8=
		&_jc_polyglot_util_Pair$method$part1$0c1e939f4cba35c8,
	    .part2$7912c7411ed9b452=
		&_jc_polyglot_util_Pair$method$part2$7912c7411ed9b452,
	},
    }
};

==> jc-1.4.5.tar.gz: polyglot/util/Pair.c <==
// public class polyglot.util.Pair

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 98b787b92ac6a3b9 polyglot_util_Pair

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header polyglot_util_Pair

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "polyglot/util/Pair.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// java.lang.Object part1
static _jc_field _jc_polyglot_util_Pair$field_info$part1 = {
	.name=		"part1",
	.signature=	"Ljava/lang/Object;",
	.class=		&_jc_polyglot_util_Pair$type,
	.type=		&_jc_java_lang_Object$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_polyglot_util_Pair$object, refs[-1].polyglot_util_Pair.part1),
};

// java.lang.Object part2
static _jc_field _jc_polyglot_util_Pair$field_info$part2 = {
	.name=		"part2",
	.signature=	"Ljava/lang/Object;",
	.class=		&_jc_polyglot_util_Pair$type,
	.type=		&_jc_java_lang_Object$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_polyglot_util_Pair$object, refs[-1].polyglot_util_Pair.part2),
};

// Fields
static _jc_field *const _jc_polyglot_util_Pair$fields[] = {
	&_jc_polyglot_util_Pair$field_info$part1,
	&_jc_polyglot_util_Pair$field_info$part2
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.Object, java.lang.Object)
//

static _jc_linenum _jc_polyglot_util_Pair$linenum_table$_init$1b34a4ef37055d19[];

static const unsigned char _jc_polyglot_util_Pair$param_ptypes$_init$1b34a4ef37055d19[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_polyglot_util_Pair$param_types$_init$1b34a4ef37055d19[] = {
	&_jc_java_lang_Object$type,
	&_jc_java_lang_Object$type
};

_jc_method _jc_polyglot_util_Pair$method_info$_init$1b34a4ef37055d19 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/Object;Ljava/lang/Object;)V",
	.class=			&_jc_polyglot_util_Pair$type,
	.param_types=		&_jc_polyglot_util_Pair$param_types$_init$1b34a4ef37055d19,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_polyglot_util_Pair$param_ptypes$_init$1b34a4ef37055d19,
	.signature_hash=	_JC_JLONG(0x1b34a4ef37055d19),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_util_Pair$method$_init$1b34a4ef37055d19,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_polyglot_util_Pair$linenum_table$_init$1b34a4ef37055d19
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_util_Pair, _init$1b34a4ef37055d19);

void _JC_JCNI_ATTR
_jc_polyglot_util_Pair$method$_init$1b34a4ef37055d19(_jc_env *const env, _jc_polyglot_util_Pair$object *this, _jc_java_lang_Object$object *param0, _jc_java_lang_Object$object *param1)
{
	struct _jc_polyglot_util_Pair$object *r0;
	struct _jc_java_lang_Object$object *r1;
	struct _jc_java_lang_Object$object *r2;

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(11);				// 0
	_JC_REF_FIELD(env, r0, polyglot_util_Pair, part1) = r1;
	_JC_LINE_NUMBER(12);				// 1
	_JC_REF_FIELD(env, r0, polyglot_util_Pair, part2) = r2;
	_JC_LINE_NUMBER(13);				// 2
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.Object part1()
//

static _jc_linenum _jc_polyglot_util_Pair$linenum_table$part1$0c1e939f4cba35c8[];

static const unsigned char _jc_polyglot_util_Pair$param_ptypes$part1$0c1e939f4cba35c8[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_polyglot_util_Pair$method_info$part1$0c1e939f4cba35c8 = {
	.name=			"part1",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_polyglot_util_Pair$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_polyglot_util_Pair$param_ptypes$part1$0c1e939f4cba35c8,
	.signature_hash=	_JC_JLONG(0xc1e939f4cba35c8),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_util_Pair$method$part1$0c1e939f4cba35c8,
	.vtable_index=		_JC_OFFSETOF(struct _jc_polyglot_util_Pair$vtable, polyglot_util_Pair.part1$0c1e939f4cba35c8) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_util_Pair$linenum_table$part1$0c1e939f4cba35c8
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_util_Pair, part1$0c1e939f4cba35c8);

_jc_java_lang_Object$object * _JC_JCNI_ATTR
_jc_polyglot_util_Pair$method$part1$0c1e939f4cba35c8(_jc_env *const env, _jc_polyglot_util_Pair$object *this)
{
	struct _jc_polyglot_util_Pair$object *r0;
	struct _jc_java_lang_Object$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(16);				// 0
	r1 = _JC_REF_FIELD(env, r0, polyglot_util_Pair, part1);
	return r1;
}

//
// public java.lang.Object part2()
//

static _jc_linenum _jc_polyglot_util_Pair$linenum_table$part2$7912c7411ed9b452[];

static const unsigned char _jc_polyglot_util_Pair$param_ptypes$part2$7912c7411ed9b452[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_polyglot_util_Pair$method_info$part2$7912c7411ed9b452 = {
	.name=			"part2",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_polyglot_util_Pair$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_polyglot_util_Pair$param_ptypes$part2$7912c7411ed9b452,
	.signature_hash=	_JC_JLONG(0x7912c7411ed9b452),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_util_Pair$method$part2$7912c7411ed9b452,
	.vtable_index=		_JC_OFFSETOF(struct _jc_polyglot_util_Pair$vtable, polyglot_util_Pair.part2$7912c7411ed9b452) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_util_Pair$linenum_table$part2$7912c7411ed9b452
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_util_Pair, part2$7912c7411ed9b452);

_jc_java_lang_Object$object * _JC_JCNI_ATTR
_jc_polyglot_util_Pair$method$part2$7912c7411ed9b452(_jc_env *const env, _jc_polyglot_util_Pair$object *this)
{
	struct _jc_polyglot_util_Pair$object *r0;
	struct _jc_java_lang_Object$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(20);				// 0
	r1 = _JC_REF_FIELD(env, r0, polyglot_util_Pair, part2);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_polyglot_util_Pair$methods[] = {
	&_jc_polyglot_util_Pair$method_info$_init$1b34a4ef37055d19,
	&_jc_polyglot_util_Pair$method_info$part1$0c1e939f4cba35c8,
	&_jc_polyglot_util_Pair$method_info$part2$7912c7411ed9b452
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_polyglot_util_Pair$instanceof_hash_bucket_57[] = {
	&_jc_polyglot_util_Pair$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_util_Pair$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_polyglot_util_Pair$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[57]=	_jc_polyglot_util_Pair$instanceof_hash_bucket_57,
	[101]=	_jc_polyglot_util_Pair$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_polyglot_util_Pair$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_polyglot_util_Pair$vtype _jc_polyglot_util_Pair$type = {
    .type= {
	.name=			"polyglot/util/Pair",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x98b787b92ac6a3b9),
		.source_file=		"Pair.java",
		.instance_size=		sizeof(_jc_polyglot_util_Pair$refs) + sizeof(_jc_polyglot_util_Pair$object),
		.num_virtual_refs=	2,
		.num_fields=		sizeof(_jc_polyglot_util_Pair$fields) / sizeof(*_jc_polyglot_util_Pair$fields),
		.fields=		_jc_polyglot_util_Pair$fields,
		.num_methods=		sizeof(_jc_polyglot_util_Pair$methods) / sizeof(*_jc_polyglot_util_Pair$methods),
		.methods=		_jc_polyglot_util_Pair$methods,
		.instanceof_hash_table=	_jc_polyglot_util_Pair$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_polyglot_util_Pair$class_depends) / sizeof(*_jc_polyglot_util_Pair$class_depends),
		.class_depends=		_jc_polyglot_util_Pair$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.polyglot_util_Pair= {
	    .part1$0c1e939f4cba35c8=
		&_jc_polyglot_util_Pair$method$part1$0c1e939f4cba35c8,
	    .part2$7912c7411ed9b452=
		&_jc_polyglot_util_Pair$method$part2$7912c7411ed9b452,
	},
    }
};
